1D waveguide string models with stiffness and damping Physical string model — digital waveguide with stiffness and damping.
Implements a 1D waveguide using a delay line with fractional-delay allpass interpolation, a loop filter for frequency-dependent damping, and an allpass dispersion filter for inharmonic stiff-string behavior.
Structs
- String
Model - Physical string model — digital waveguide with damping and dispersion.
- String
Params - Parameters for a physical string model.