Module wdf

Module wdf 

WDF-based filter models WDF-based filters.

These filters use Wave Digital Filter elements and adapters to model analog circuits, providing authentic analog behavior.

Structs

DiodeClipper
Series composite of two WDF elements.
MoogLadder
Cascaded WDF filter made of identical sections.
RcPole
A single WDF element.